@@ -1,10 +1,11 @@
 package Mojo::Redis;
 
-our $VERSION = eval '0.9901';
+our $VERSION = eval '0.9902';
 use Mojo::Base 'Mojo::EventEmitter';
 
 use Mojo::IOLoop;
 use Mojo::Redis::Subscription;
+use Mojo::URL;
 use Scalar::Util ();
 use Encode       ();
 use Carp;
@@ -76,15 +77,24 @@ sub DESTROY {
 
 sub connect {
   my $self = shift;
+  my($url, $auth, $db_index);
+
+  if($self->server =~ m{^[^:]+:\d+$}) {
+    $url = Mojo::URL->new('redis://' .$self->server);
+  }
+  else {
+    $url = Mojo::URL->new($self->server);
+  }
 
   Scalar::Util::weaken $self;
+  $auth = (split /:/, $url->userinfo || '')[1];
+  $db_index = ($url->path =~ /(\d+)/)[0];
 
   $self->disconnect; # drop old connection
-  $self->server =~ m{^([^:]+)(?::(\d+))?};
   $self->{_connecting} = 1;
   $self->{_connection} = $self->ioloop->client(
-    { address => $1,
-      port    => $2 || 6379,
+    { address => $url->host,
+      port    => $url->port || 6379,
     },
     sub {
       my ($loop, $error, $stream) = @_;
@@ -124,6 +134,18 @@ sub connect {
         }
       );
 
+      my $mqueue = $self->{_message_queue} ||= [];
+      my $cqueue = $self->{_cb_queue} ||= [];
+
+      if(defined $db_index) { # need to be before defined $auth below
+        unshift @$mqueue, [ SELECT => $db_index ];
+        unshift @$cqueue, sub {}; # no error handling needed. got on(error => ...)
+      }
+      if(defined $auth) {
+        unshift @$mqueue, [ AUTH => $auth ];
+        unshift @$cqueue, sub {}; # no error handling needed. got on(error => ...)
+      }
+
       delete $self->{_connecting};
       $self->_send_next_message;
     }
@@ -430,8 +452,12 @@ L<Mojo::Redis> implements the following attributes.
 
     my $server = $redis->server;
     $redis     = $redis->server('127.0.0.1:6379');
+    $redis     = $redis->server('redis://anything:PASSWORD@127.0.0.1:6379/DB_INDEX');
 
-C<Redis> server connection string, defaults to '127.0.0.1:6379'.
+C<Redis> server connection string, defaults to '127.0.0.1:6379'. The
+latter can be used if you want L<Mojo::Redis> to automatically run L</auth>
+with C<PASSWORD> and/or L</select> with C<DB_INDEX> on connect. Both AUTH
+and DB_INDEX are optional.
 
 =head2 ioloop
 
@@ -513,6 +539,8 @@ the L</error> event.
 
 =head2 auth
 
+See L</server> instead.
+
 =head2 bgrewriteaof
 
 =head2 bgsave
@@ -671,6 +699,8 @@ the L</error> event.
 
 =head2 select
 
+See L</server> instead.
+
 =head2 set
 
 =head2 setbit
